## Script: teams.py
## Author: Joseph Armstrong (armstjc)

from re import search
import pandas as pd
from pandas import json_normalize
import json
from datetime import datetime
from sportsdataverse.dl_utils import download

import os


def getTeamData(season:int,retriveAllStarRosters=False):
	'''
	Retrives the player info for an MLB team, given an MLB season

	Args:
	
	season (int):
		Required paramater. If no season is provided, the function wil not work.

	retriveAllStarRosters (boolean):
		Optional parameter. If set to 'True', MLB All-Star rosters will be returned when 
		running this function.
	'''
	#pullCopyrightInfo()
	#p_df = pd.DataFrame()
	main_df = pd.DataFrame()
	
	searchURL = "http://lookup-service-prod.mlb.com/json/named.team_all_season.bam?sport_code='mlb'&"

	if retriveAllStarRosters == True:
		searchURL = searchURL + 'all_star_sw=\'Y\'&'
	else:
		searchURL = searchURL + 'all_star_sw=\'N\'&'

	now = datetime.now()

	if season < 1860 or season == None:
		print('1_Please input a proper year. The search will continue with the current year instead.')
		season = int(now.year)
		searchURL = searchURL  + f'sort_order=\'name_asc\'&season=\'{season}\''
	elif int(now.year) < season:
		print('0_Please input a proper year. The search will continue with the current year instead.')
		season = int(now.year)
		searchURL = searchURL  + f'sort_order=\'name_asc\'&season=\'{season}\''
	else:
		searchURL = searchURL  + f'sort_order=\'name_asc\'&season=\'{season}\''

	resp = download(searchURL)

	#print(searchURL)
	resp_str = str(resp, 'UTF-8')
	#print(resp_str)

	resp_json = json.loads(resp_str)
	try:
		result_count = int(resp_json['team_all_season']['queryResults']['totalSize'])
	except:
		result_count = 0

	if result_count > 0:
		#print(resp_json['player_teams']['queryResults']['row'])

		print(f'{result_count} statlines found,\nParsing results into a dataframe.')
		#players = resp_json['search_player_all']['queryResults']['row']
		main_df = json_normalize(resp_json['team_all_season']['queryResults']['row']) 
		print('Done')
	else:
		print(f'No results found for the provided playerID. \nTry a diffrient search for better results.')
		
	return main_df

def get40ManRoster(teamID:int):
	'''
	Retrives the player info for an MLB player, given a proper MLBAM ID

	Args:
	
	teamID (int):
		Required paramater. This should be the number MLBAM associates for an MLB team.
		For example, the Cincinnati Reds have an MLBAM team ID of 113.
	'''
	#pullCopyrightInfo()
	
	main_df = pd.DataFrame()
	
	searchURL = 'http://lookup-service-prod.mlb.com/json/named.roster_40.bam?team_id='

	searchURL = searchURL + f'\'{teamID}\''	

	resp = download(searchURL)

	#print(searchURL)
	resp_str = str(resp, 'UTF-8')
	#print(resp_str)

	resp_json = json.loads(resp_str)
	try:
		result_count = int(resp_json['roster_40']['queryResults']['totalSize'])
	except:
		result_count = 0

	if result_count > 0:
		#print(resp_json['player_teams']['queryResults']['row'])

		print(f'{result_count} statlines found,\nParsing results into a dataframe.')
		#players = resp_json['search_player_all']['queryResults']['row']
		main_df = json_normalize(resp_json['roster_40']['queryResults']['row']) 
		print('Done')
	else:
		print(f'No results found for the provided playerID. \nTry a diffrient search for better results.')
		
	return main_df

def getAllTimeRoster(teamID:int,startSeason:int,endSeason:int):
	'''
	Retrives the cumulative roster for a MLB team in a specified timeframe.

	Args:
	
	teamID (int):
		Required paramater. This should be the number MLBAM associates for an MLB team.
		For example, the Cincinnati Reds have an MLBAM team ID of 113.

	startSeason (int):
		Required parameter. This value must be less than endSeason for this function to work.
		
	endSeason (int):
		Required parameter. This value must be greater than startSeason for this function to work.
	'''
	#pullCopyrightInfo()
	
	holding_num = 0
	main_df = pd.DataFrame()
	
	if endSeason < startSeason:
		holding_num = endSeason
		startSeason = endSeason
		endSeason = holding_num
	else:
		pass

	searchURL = 'http://lookup-service-prod.mlb.com/json/named.roster_team_alltime.bam?'

	## Add the Season ranges

	searchURL = searchURL + f'start_season=\'{startSeason}\'&end_season=\'{endSeason}\'&'
	## Add the TeamID
	searchURL = searchURL + f'team_id=\'{teamID}\''	

	resp = download(searchURL)

	#print(searchURL)
	
	resp_str = str(resp, 'latin-1')
	#print(resp_str)

	resp_json = json.loads(resp_str)
	try:
		result_count = int(resp_json['roster_team_alltime']['queryResults']['totalSize'])
	except:
		result_count = 0

	if result_count > 0:
		#print(resp_json['player_teams']['queryResults']['row'])

		print(f'{result_count} statlines found,\nParsing results into a dataframe.')
		#players = resp_json['search_player_all']['queryResults']['row']
		main_df = json_normalize(resp_json['roster_team_alltime']['queryResults']['row']) 
		print('Done')
	else:
		print(f'No results found for the provided playerID. \nTry a diffrient search for better results.')
		
	return main_df


from re import search
import pandas as pd
from pandas import json_normalize
import json
from datetime import datetime
from sportsdataverse.dl_utils import download

import os
def pullCopyrightInfo(saveFile=False,returnFile=False):
	"""
	Displays the copyright info for the MLBAM API.

	Args:
	saveFile (boolean) = False
		If saveFile is set to True, the copyright file generated is saved.

	returnFile (boolean) = False
		If returnFile is set to True, the copyright file is returned.
	"""
	url = "http://gdx.mlb.com/components/copyright.txt"
	resp = download(url=url)
	try:
		
		if resp is not None:
			l_string = str(resp, 'UTF-8')
			with open("mlbam_copyright.txt","w+" ,encoding = "utf-8") as file:
				file.writelines(str(l_string))

			with open("mlbam_copyright.txt", "r" ,encoding = "utf-8") as file:
				mlbam = file.read()

			if saveFile == False:
				if os.path.exists("mlbam_copyright.txt"):
					os.remove("mlbam_copyright.txt")
				else:
					pass
			else:
				pass
			print(mlbam)

			if returnFile == True:
				return mlbam
			else:
				pass


		else:
			print('Could not connect to the internet. \nPlease fix this issue to be able to use this package.')
	except:
		print('Could not connect to the internet. \nPlease fix this issue to be able to use this package.')


## Script: players.py
## Author: Joseph Armstrong (armstjc)

import pandas as pd
from pandas import json_normalize
import json
from sportsdataverse.dl_utils import download
from tqdm import tqdm

import os

def searchMlbPlayers(search:str,isActive=""):
	"""
	Searches for an MLB player in the MLBAM API.
	
	Args:
	search (string):
		Inputted string of the player(s) the user is intending to search.
		If there is nothin inputted, nothing will be searched.
	
	isActive (string, optional):
		If called, it will specify if you want active players, or innactive players
		in your search.

		If you want active players, set isActive to "Y" or "Yes".

		If you want inactive players, set isActive to "N" or "No".
	"""
	#pullCopyrightInfo()
	searchURL = "http://lookup-service-prod.mlb.com/json/named.search_player_all.bam?sport_code='mlb'"
	
	p_df = pd.DataFrame()
	main_df = pd.DataFrame()

	if len(isActive) == 0:
		#print('Searching for all MLB players.')
		print('')
	elif isActive.lower() == "y" or isActive.lower() == "yes":
		searchURL = searchURL + "&active_sw='Y'"
	elif isActive.lower() == "n" or isActive.lower() == "no":
		searchURL = searchURL + "&active_sw='N'"
	else:
		print('Improper input for the isActive input. \nIf you want active players, set isActive to "Y" or "Yes". \nIf you want inactive players, set isActive to "N" or "No".\n\nIn the meantime, your search will search for all players in MLB history.')

	if len(search) > 0:
		print(f"Searching for a player nammed \"{search}\".")
		
		searchURL= searchURL + f"&name_part='{search}%25'"
		
		
		#searchURL = urllib.parse.quote_plus(str(searchURL))
		resp = download(searchURL)

		
		resp_str = str(resp, 'UTF-8')
		#print(resp_str)

		resp_json = json.loads(resp_str)
		result_count = int(resp_json['search_player_all']['queryResults']['totalSize'])
		if result_count > 0:
			print(f'{result_count} players found,\nParsing results into a dataframe.')

			for i in resp_json['search_player_all']['queryResults']['row']:

				p_df = json_normalize(resp_json['search_player_all']['queryResults']['row']) 
				main_df = pd.concat([p_df,main_df],ignore_index=True)
		else:
			print(f'No results found for {search}. \nTry a diffrient search for better results.')
		main_df.drop_duplicates(subset="player_id",keep="first",inplace=True)
		return main_df
		

	else:
		print("To search for MLB players in the MLBAM API, you must include text relating to the player you're searching for.")

def getPlayerInfo(playerID:int):
	'''
	Retrives the player info for an MLB player, given a proper MLBAM ID

	Args:
	
	playerID (int):
		Required paramater. If no playerID is provided, the function wil not work.
	'''
	#pullCopyrightInfo()
	#p_df = pd.DataFrame()
	main_df = pd.DataFrame()
	
	searchURL = "http://lookup-service-prod.mlb.com/json/named.player_info.bam?sport_code='mlb'&player_id="

	if playerID < 1:
		print('You must provide a playerID. Without a proper playerID, this function will not work.')
		return None
	else:
		searchURL= searchURL + f"\'{playerID}\'%27"
		
		
		#searchURL = urllib.parse.quote_plus(str(searchURL))
		resp = download(searchURL)

		#print(searchURL)
		resp_str = str(resp, 'UTF-8')
		#print(resp_str)

		resp_json = json.loads(resp_str)
		try:
			result_count = int(resp_json['player_info']['queryResults']['totalSize'])
		except:
			result_count = 0

		if result_count > 0:
			#print(resp_json['player_info']['queryResults']['row'])

			#print(f'{result_count} players found,\nParsing results into a dataframe.')
			#players = resp_json['search_player_all']['queryResults']['row']
			main_df = json_normalize(resp_json['player_info']['queryResults']['row']) 
			print('Done')
		else:
			print(f'No results found for the provided playerID. \nTry a diffrient search for better results.')
		
		return main_df

def getPlayerTeams(playerID:int,season:int):
	'''
	Retrives the info regarding which teams that player played for in a given
	season, or in the player's career

	Args:
	
	playerID (int):
		Required paramater. If no playerID is provided, the function wil not work.

	season (int):
		Required parameter. If provided, the search will only look for teams 
		that player played for in that season.
	'''
	#pullCopyrightInfo()
	#p_df = pd.DataFrame()
	main_df = pd.DataFrame()
	
	searchURL = "http://lookup-service-prod.mlb.com/json/named.player_teams.bam?"

	if season >1 and season < 1860:
		print('Enter a valid season. Baseball wasn\'t really a thing in the year you spefified.')
	elif season > 1860:
		searchURL = searchURL + f'season=\'{season}\'&'
	else:
		print('Searching for all the teams this player has played on')

	if playerID < 1:
		print('You must provide a playerID. Without a proper playerID, this function will not work.')
		return None
	else:
		searchURL= searchURL + f"player_id=\'{playerID}\'"
		
		
		#searchURL = urllib.parse.quote_plus(str(searchURL))
		resp = download(searchURL)

		#print(searchURL)
		resp_str = str(resp, 'UTF-8')
		#print(resp_str)

		resp_json = json.loads(resp_str)
		try:
			result_count = int(resp_json['player_teams']['queryResults']['totalSize'])
		except:
			result_count = 0

		if result_count > 0:
			#print(resp_json['player_teams']['queryResults']['row'])

			print(f'{result_count} players found,\nParsing results into a dataframe.')
			#players = resp_json['search_player_all']['queryResults']['row']
			main_df = json_normalize(resp_json['player_teams']['queryResults']['row']) 
			print('Done')
		else:
			print(f'No results found for the provided playerID. \nTry a diffrient search for better results.')
		
		return main_df



## Script: stats.py
## Author: Joseph Armstrong (armstjc)

import pandas as pd
from pandas import json_normalize
import json
from sportsdataverse.dl_utils import download
from datetime import datetime

import os



def getSeasonHittingStats(playerID:int,season:int,gameType="R"):
	'''
	Retrives the hitting stats for an MLB player in a given season, given a proper MLBAM ID

	Args:
	
	playerID (int):
		Required paramater. If no playerID is provided, the function wil not work.

	season (int):
		Required paramater. Indicates the season you are trying to find the games for.

	gameType (string) = "R":
		Optional parameter. If there's no input, this function will get the info for the regular season.

		Other parts of the season are indicated as follows in the MLBAM API:
		
		'S' - Spring Training
		'E' - Exhibition
		'A' - All Star Game
		'D' - Division Series
		'F' - First Round (Wild Card)
		'L' - League Championship
		'W' - World Series
	'''
	#pullCopyrightInfo()
	#p_df = pd.DataFrame()
	main_df = pd.DataFrame()
	
	searchURL = "http://lookup-service-prod.mlb.com/json/named.sport_hitting_tm.bam?league_list_id='mlb'&"

	if len(gameType) >1:
		print('Check your input for seasonType. Searching for regular season stats instead.')
		gameType = "R"
		searchURL = searchURL  + f'game_type=\'{gameType}\'&'
	else:
		pass

	if gameType == "R" or gameType == "S" or gameType == "E" or gameType == "A" or gameType == "D" or gameType == "F" or gameType == "L" or gameType == "W":
		searchURL = searchURL  + f'game_type=\'{gameType}\'&'
	else:
		print('Check your input for seasonType. Searching for regular season stats instead.')
		gameType = "R"
		searchURL = searchURL  + f'game_type=\'{gameType}\'&'

	now = datetime.now()
	if season < 1860 or season == None:
		print('Please input a proper year. The search will continue with the current year instead.')
		season = int(now.year)
		searchURL = searchURL  + f'season=\'{season}\'&'
	elif int(now.year) < season:
		print('Please input a proper year. The search will continue with the current year instead.')
		season = int(now.year)
		searchURL = searchURL  + f'season=\'{season}\'&'
	else:
		searchURL = searchURL  + f'season=\'{season}\'&'



	if playerID < 1 or playerID == None or season == None or season < 1860:
		print('You must provide a playerID and a proper season. Function aborted.')
		return None
	else:
		searchURL= searchURL + f"player_id=\'{playerID}\'"
		
		
		#searchURL = urllib.parse.quote_plus(str(searchURL))
		resp = download(searchURL)

		#print(searchURL)
		resp_str = str(resp, 'UTF-8')
		#print(resp_str)

		resp_json = json.loads(resp_str)
		try:
			result_count = int(resp_json['sport_hitting_tm']['queryResults']['totalSize'])
		except:
			result_count = 0

		if result_count > 0:
			#print(resp_json['player_teams']['queryResults']['row'])

			print(f'{result_count} statlines found,\nParsing results into a dataframe.')
			#players = resp_json['search_player_all']['queryResults']['row']
			main_df = json_normalize(resp_json['sport_hitting_tm']['queryResults']['row']) 
			print('Done')
		else:
			print(f'No results found for the provided playerID. \nTry a diffrient search for better results.')
		
		return main_df


def getSeasonPitchingStats(playerID:int,season:int,gameType="R"):
	'''
	Retrives the pitching stats for an MLB player in a given season, given a proper MLBAM ID

	Args:
	
	playerID (int):
		Required paramater. If no playerID is provided, the function wil not work.

	season (int):
		Required paramater. Indicates the season you are trying to find the games for.

	gameType (string) = "R":
		Optional parameter. If there's no input, this function will get the info for the regular season.

		Other parts of the season are indicated as follows in the MLBAM API:
		
		'S' - Spring Training
		'E' - Exhibition
		'A' - All Star Game
		'D' - Division Series
		'F' - First Round (Wild Card)
		'L' - League Championship
		'W' - World Series
	'''
	#pullCopyrightInfo()
	#p_df = pd.DataFrame()
	main_df = pd.DataFrame()
	
	searchURL = "http://lookup-service-prod.mlb.com/json/named.sport_pitching_tm.bam?league_list_id='mlb'&"

	if len(gameType) >1:
		print('Check your input for seasonType. Searching for regular season stats instead.')
		gameType = "R"
	
	if gameType == "R" or gameType == "S" or gameType == "E" or gameType == "A" or gameType == "D" or gameType == "F" or gameType == "L" or gameType == "W":
		searchURL = searchURL  + f'game_type=\'{gameType}\'&'
	else:
		print('Check your input for seasonType. Searching for regular season stats instead.')
		gameType = "R"
		searchURL = searchURL  + f'game_type=\'{gameType}\'&'

	now = datetime.now()
	if season < 1860 or season == None:
		print('Please input a proper year. The search will continue with the current year instead.')
		season = int(now.year)
		searchURL = searchURL  + f'season=\'{season}\'&'
	elif int(now.year) < season:
		print('Please input a proper year. The search will continue with the current year instead.')
		season = int(now.year)
		searchURL = searchURL  + f'season=\'{season}\'&'
	else:
		searchURL = searchURL  + f'season=\'{season}\'&'



	if playerID < 1 or playerID == None:
		print('You must provide a playerID. Without a proper playerID, this function will not work.')
		return None
	else:
		searchURL= searchURL + f"player_id=\'{playerID}\'"
		
		
		#searchURL = urllib.parse.quote_plus(str(searchURL))
		resp = download(searchURL)

		#print(searchURL)
		resp_str = str(resp, 'UTF-8')
		#print(resp_str)

		resp_json = json.loads(resp_str)
		try:
			result_count = int(resp_json['sport_pitching_tm']['queryResults']['totalSize'])
		except:
			result_count = 0

		if result_count > 0:
			#print(resp_json['player_teams']['queryResults']['row'])

			print(f'{result_count} statlines found,\nParsing results into a dataframe.')
			#players = resp_json['search_player_all']['queryResults']['row']
			main_df = json_normalize(resp_json['sport_pitching_tm']['queryResults']['row']) 
			print('Done')
		else:
			print(f'No results found for the provided playerID. \nTry a diffrient search for better results.')
		
		return main_df


def getCareerHittingStats(playerID:int,gameType="R"):
	'''
	Retrives the career hitting stats for an MLB player, given a proper MLBAM ID

	Args:
	
	playerID (int):
		Required paramater. If no playerID is provided, the function wil not work.

	gameType (string) = "R":
		Optional parameter. If there's no input, this function will get the info for the regular season.

		Other parts of the season are indicated as follows in the MLBAM API:
		
		'S' - Spring Training
		'E' - Exhibition
		'A' - All Star Game
		'D' - Division Series
		'F' - First Round (Wild Card)
		'L' - League Championship
		'W' - World Series
	'''
	#pullCopyrightInfo()
	#p_df = pd.DataFrame()
	main_df = pd.DataFrame()
	
	searchURL = "http://lookup-service-prod.mlb.com/json/named.sport_career_hitting.bam?league_list_id='mlb'&"

	if len(gameType) >1:
		print('Check your input for seasonType. Searching for regular season stats instead.')
		gameType = "R"
		searchURL = searchURL  + f'game_type=\'{gameType}\'&'
	else:
		pass

	if gameType == "R" or gameType == "S" or gameType == "E" or gameType == "A" or gameType == "D" or gameType == "F" or gameType == "L" or gameType == "W":
		searchURL = searchURL  + f'game_type=\'{gameType}\'&'
	else:
		print('Check your input for seasonType. Searching for regular season stats instead.')
		gameType = "R"
		searchURL = searchURL  + f'game_type=\'{gameType}\'&'




	if playerID < 1 or playerID == None:
		print('You must provide a playerID. Without a proper playerID, this function will not work.')
		return None
	else:
		searchURL= searchURL + f"player_id=\'{playerID}\'"
		
		
		#searchURL = urllib.parse.quote_plus(str(searchURL))
		resp = download(searchURL)

		#print(searchURL)
		resp_str = str(resp, 'UTF-8')
		#print(resp_str)

		resp_json = json.loads(resp_str)
		try:
			result_count = int(resp_json['sport_career_hitting']['queryResults']['totalSize'])
		except:
			result_count = 0

		if result_count > 0:
			#print(resp_json['player_teams']['queryResults']['row'])

			print(f'{result_count} statlines found,\nParsing results into a dataframe.')
			#players = resp_json['search_player_all']['queryResults']['row']
			main_df = json_normalize(resp_json['sport_career_hitting']['queryResults']['row']) 
			print('Done')
		else:
			print(f'No results found for the provided playerID. \nTry a diffrient search for better results.')
		
		return main_df


def getCareerPitchingStats(playerID:int,gameType="R"):
	'''
	Retrives the career pitching stats for an MLB player, given a proper MLBAM ID

	Args:
	
	playerID (int):
		Required paramater. If no playerID is provided, the function wil not work.

	gameType (string) = "R":
		Optional parameter. If there's no input, this function will get the info for the regular season.

		Other parts of the season are indicated as follows in the MLBAM API:
		
		'S' - Spring Training
		'E' - Exhibition
		'A' - All Star Game
		'D' - Division Series
		'F' - First Round (Wild Card)
		'L' - League Championship
		'W' - World Series
	'''
	#pullCopyrightInfo()
	#p_df = pd.DataFrame()
	main_df = pd.DataFrame()
	
	searchURL = "http://lookup-service-prod.mlb.com/json/named.sport_career_pitching.bam?league_list_id='mlb'&"

	if len(gameType) >1:
		print('Check your input for seasonType. Searching for regular season stats instead.')
		gameType = "R"
		searchURL = searchURL  + f'game_type=\'{gameType}\'&'
	else:
		pass

	if gameType == "R" or gameType == "S" or gameType == "E" or gameType == "A" or gameType == "D" or gameType == "F" or gameType == "L" or gameType == "W":
		searchURL = searchURL  + f'game_type=\'{gameType}\'&'
	else:
		print('Check your input for seasonType. Searching for regular season stats instead.')
		gameType = "R"
		searchURL = searchURL  + f'game_type=\'{gameType}\'&'

	if playerID < 1 or playerID == None:
		print('You must provide a playerID. Without a proper playerID, this function will not work.')
		return None
	else:
		searchURL= searchURL + f"player_id=\'{playerID}\'"
		
		
		#searchURL = urllib.parse.quote_plus(str(searchURL))
		resp = download(searchURL)

		#print(searchURL)
		resp_str = str(resp, 'UTF-8')
		#print(resp_str)

		resp_json = json.loads(resp_str)
		try:
			result_count = int(resp_json['sport_career_pitching']['queryResults']['totalSize'])
		except:
			result_count = 0

		if result_count > 0:
			#print(resp_json['player_teams']['queryResults']['row'])

			print(f'{result_count} statlines found,\nParsing results into a dataframe.')
			#players = resp_json['search_player_all']['queryResults']['row']
			main_df = json_normalize(resp_json['sport_career_pitching']['queryResults']['row'])
			print('Done')
		else:
			print(f'No results found for the provided playerID. \nTry a diffrient search for better results.')
		
		return main_df


## Script: reports.py
## Author: Joseph Armstrong (armstjc)

import pandas as pd
from pandas import json_normalize
import json
from sportsdataverse.dl_utils import download
from datetime import datetime

import os




def getTransactionsInRange(startDate:str,endDate:str):
	'''
	Retrives all transactions in a given range of dates.
	You MUST provide two dates for this function to work, and both dates must 
	be in YYYYMMDD format. For example, December 31st, 2021 would be represented
	as 20211231

	Args:
	
	startDate (int):
		Required paramater. If no startDate is provided, the function wil not work.
		Additionally, startDate must be in YYYYMMDD format.

	endDate (int):
		Required paramater. If no endDate is provided, the function wil not work.
		Additionally, endDate must be in YYYYMMDD format.
	'''
	#pullCopyrightInfo()
	#p_df = pd.DataFrame()
	main_df = pd.DataFrame()
	
	searchURL = "http://lookup-service-prod.mlb.com/json/named.transaction_all.bam?sport_code='mlb'&"

	try:
		#sd = int(startDate)
		#ed = int(endDate)
		sd_date = datetime.strptime(startDate, '%m/%d/%Y')
		ed_date = datetime.strptime(endDate, '%m/%d/%Y')
		sd = sd_date.strftime("%Y%m%d")
		ed = ed_date.strftime("%Y%m%d")

		if sd > ed:
			print('There is an issue with your inputted dates.\nPlease verify that your start date is older than your end date.')
			return None
			
		diff_days = ed_date.date() - sd_date.date()
		if (diff_days.days)> 30:
			print('Getting transaction data. This will take some time.')
		else:
			print('Getting transaction data.')
		#print(sd,ed)
		searchURL = searchURL + f'start_date=\'{sd}\''
		searchURL = searchURL + f'start_date=\'{ed}\''
		
		
	except:
		print('There\'s an issue with the way you\'ve formmatted you inputs.')

	try:
		resp = download(searchURL)

		#print(searchURL)
		resp_str = str(resp, 'UTF-8')
		#print(resp_str)

		resp_json = json.loads(resp_str)
		try:
			result_count = int(resp_json['transaction_all']['queryResults']['totalSize'])
		except:
			result_count = 0

		if result_count > 0:
			#print(resp_json['player_teams']['queryResults']['row'])

			print(f'{result_count} statlines found,\nParsing results into a dataframe.')
			#players = resp_json['search_player_all']['queryResults']['row']
			main_df = json_normalize(resp_json['transaction_all']['queryResults']['row']) 
			print('Done')
		else:
			print(f'No results found for the provided playerID. \nTry a diffrient search for better results.')
		
		return main_df
	except:
		print('Could not locate dates ')

def getBroadcastInfo(season:int,home_away="e"):
	'''
	Retrives the broadcasters (radio and TV) involved with certian games.

	Args:
	
	season (int):
		Required paramater. If no season is provided, the function wil not work.

	home_away (string):
		Optional paramater. Used to get broadcasters from either the home OR the away side.
		Leave blank if you want both home and away broadcasters.

		If you want home broadcasters only, set home_away='H' or home_away='a'.

		If you want away broadcasters only, set home_away='A' or home_away='a'.

		If you want both home and away broadcasters, set home_away='E' or home_away='e'.
	'''
	#pullCopyrightInfo()
	#p_df = pd.DataFrame()
	main_df = pd.DataFrame()
	
	searchURL = "http://lookup-service-prod.mlb.com/json/named.mlb_broadcast_info.bam?tcid=mm_mlb_schedule&"

	if home_away.lower() == "a":
		searchURL = searchURL + '&home_away=\'A\''
	elif home_away.lower() == "h":
		searchURL = searchURL + '&home_away=\'H\''
	elif home_away.lower() == "e":
		searchURL = searchURL + '&home_away=\'E\''
	else:
		pass
	
	now = datetime.now()

	if season >1860 and season < now.year:
		searchURL = searchURL + f'&season=\'{season}\''

		resp = download(searchURL)

		#print(searchURL)
		resp_str = str(resp, 'UTF-8')
		#print(resp_str)

		resp_json = json.loads(resp_str)
		try:
			result_count = int(resp_json['mlb_broadcast_info']['queryResults']['totalSize'])
		except:
			result_count = 0

		if result_count > 0:
			#print(resp_json['player_teams']['queryResults']['row'])

			print(f'{result_count} statlines found,\nParsing results into a dataframe.')
			#players = resp_json['search_player_all']['queryResults']['row']
			main_df = json_normalize(resp_json['mlb_broadcast_info']['queryResults']['row']) 
			print('Done')
		else:
			print(f'No results found for the provided inputs. \nTry a diffrient search for better results.')
		
		return main_df
	else:
		print('Please enter a valid year to use this function.')




SGITHUB = 'https://raw.githubusercontent.com/sportsdataverse/'
NFLVERSEGITHUB='https://raw.githubusercontent.com/nflverse/'

CFB_BASE_URL = SGITHUB+'cfbfastR-data/main/pbp/parquet/play_by_play_{season}.parquet'
CFB_ROSTER_URL = SGITHUB+'cfbfastR-data/main/rosters/parquet/rosters_{season}.parquet'
CFB_TEAM_LOGO_URL  = SGITHUB+'cfbfastR-data/main/teams/teams_colors_logos.parquet'
CFB_TEAM_SCHEDULE_URL = SGITHUB+'cfbfastR-data/main/schedules/parquet/schedules_{season}.parquet'
CFB_TEAM_INFO_URL = SGITHUB+'cfbfastR-data/main/team_info/parquet/team_info_{season}.parquet'

NFL_BASE_URL = NFLVERSEGITHUB+'nflfastR-data/master/data/play_by_play_{season}.parquet'
NFL_PLAYER_STATS_URL = NFLVERSEGITHUB+'nflfastR-data/master/data/player_stats.parquet'
NFL_ROSTER_URL = NFLVERSEGITHUB+'nflfastR-roster/master/data/nflfastR-roster.csv.gz'
NFL_TEAM_LOGO_URL  = NFLVERSEGITHUB+'nflfastR-data/master/teams_colors_logos.csv'
NFL_TEAM_SCHEDULE_URL = SGITHUB+'nflfastR-data/master/schedules/sched_{season}.parquet'

NHL_BASE_URL = SGITHUB+'fastRhockey-data/main/nhl/pbp/parquet/play_by_play_{season}.parquet'
NHL_PLAYER_BOX_URL = SGITHUB+'fastRhockey-data/main/nhl/player_box/parquet/player_box_{season}.parquet'
NHL_TEAM_BOX_URL = SGITHUB+'fastRhockey-data/main/nhl/team_box/parquet/team_box_{season}.parquet'
NHL_TEAM_SCHEDULE_URL = SGITHUB+'fastRhockey-data/main/nhl/schedules/parquet/nhl_schedule_{season}.parquet'
NHL_TEAM_LOGO_URL  = SGITHUB+'fastRhockey-data/main/nhl/nhl_teams_colors_logos.csv'

PHF_BASE_URL = SGITHUB+'fastRhockey-data/main/phf/pbp/parquet/play_by_play_{season}.parquet'
PHF_PLAYER_BOX_URL = SGITHUB+'fastRhockey-data/main/phf/player_box/parquet/player_box_{season}.parquet'
PHF_TEAM_BOX_URL = SGITHUB+'fastRhockey-data/main/phf/team_box/parquet/team_box_{season}.parquet'
PHF_TEAM_SCHEDULE_URL = SGITHUB+'fastRhockey-data/main/phf/schedules/parquet/phf_schedule_{season}.parquet'

MBB_BASE_URL = SGITHUB+'hoopR-data/master/mbb/pbp/parquet/play_by_play_{season}.parquet'
MBB_TEAM_BOX_URL = SGITHUB+'hoopR-data/master/mbb/team_box/parquet/team_box_{season}.parquet'
MBB_PLAYER_BOX_URL = SGITHUB+'hoopR-data/master/mbb/player_box/parquet/player_box_{season}.parquet'
MBB_TEAM_LOGO_URL  = SGITHUB+'hoopR-data/master/mbb/teams_colors_logos.csv'
MBB_TEAM_SCHEDULE_URL = SGITHUB+'hoopR-data/master/mbb/schedules/parquet/mbb_schedule_{season}.parquet'

NBA_BASE_URL = SGITHUB+'hoopR-data/master/nba/pbp/parquet/play_by_play_{season}.parquet'
NBA_TEAM_BOX_URL = SGITHUB+'hoopR-data/master/nba/team_box/parquet/team_box_{season}.parquet'
NBA_PLAYER_BOX_URL  = SGITHUB+'hoopR-data/master/nba/player_box/parquet/player_box_{season}.parquet'
NBA_TEAM_SCHEDULE_URL = SGITHUB+'hoopR-data/master/nba/schedules/parquet/nba_schedule_{season}.parquet'

WBB_BASE_URL = SGITHUB+'wehoop-data/master/wbb/pbp/parquet/play_by_play_{season}.parquet'
WBB_TEAM_BOX_URL = SGITHUB+'wehoop-data/master/wbb/team_box/parquet/team_box_{season}.parquet'
WBB_PLAYER_BOX_URL = SGITHUB+'wehoop-data/master/wbb/player_box/parquet/player_box_{season}.parquet'
WBB_TEAM_LOGO_URL  = SGITHUB+'wehoop-data/master/wbb/teams_colors_logos.csv'
WBB_TEAM_SCHEDULE_URL = SGITHUB+'wehoop-data/master/wbb/schedules/parquet/wbb_schedule_{season}.parquet'

WNBA_BASE_URL = SGITHUB+'wehoop-data/master/wnba/pbp/parquet/play_by_play_{season}.parquet'
WNBA_TEAM_BOX_URL = SGITHUB+'wehoop-data/master/wnba/team_box/parquet/team_box_{season}.parquet'
WNBA_PLAYER_BOX_URL  = SGITHUB+'wehoop-data/master/wnba/player_box/parquet/player_box_{season}.parquet'
WNBA_TEAM_SCHEDULE_URL = SGITHUB+'wehoop-data/master/wnba/schedules/parquet/wnba_schedule_{season}.parquet'




from sportsdataverse.mlb.mlb_loaders import *
from sportsdataverse.mlb.mlbam_games import *
from sportsdataverse.mlb.mlbam_players import *
from sportsdataverse.mlb.mlbam_reports import *
from sportsdataverse.mlb.mlbam_stats import *
from sportsdataverse.mlb.mlbam_teams import *


## Script: games.py
## Author: Joseph Armstrong (armstjc)

import pandas as pd
from pandas import json_normalize
import json
from sportsdataverse.dl_utils import download
from datetime import datetime
import os


def getGamesInSeason(season:int,gameType="R"):
	'''
	Retrives the start and end date for games for every leauge, and the MLB, 
	for a given season. 

	This function does not get individual games.

	Args:
	
	season (int):
		Required paramater. Indicates the season you are trying to find the games for.

	gameType (string) = "R":
		Optional parameter. If there's no input, this function will get the info for the regular season.

		Other parts of the season are indicated as follows in the MLBAM API:
		
		'S' - Spring Training
		'E' - Exhibition
		'A' - All Star Game
		'D' - Division Series
		'F' - First Round (Wild Card)
		'L' - League Championship
		'W' - World Series
	'''
	#pullCopyrightInfo()
	#p_df = pd.DataFrame()
	main_df = pd.DataFrame()
	
	searchURL = "http://lookup-service-prod.mlb.com/json/named.org_game_type_date_info.bam?current_sw='Y'&sport_code='mlb'&"

	if gameType == "R" or gameType == "S" or gameType == "E" or gameType == "A" or gameType == "D" or gameType == "F" or gameType == "L" or gameType == "W":
		searchURL = searchURL  + f'game_type=\'{gameType}\'&'
	else:
		print('Check your input for seasonType. Searching for regular season stats instead.')
		gameType = "R"
		searchURL = searchURL  + f'game_type=\'{gameType}\'&'

	now = datetime.now()
	if season < 1860:
		print('Please input a proper year. The search will continue with the current year instead.')
		season = int(now.year)
		searchURL = searchURL  + f'season=\'{season}\''
	elif int(now.year) < season:
		print('Please input a proper year. The search will continue with the current year instead.')
		season = int(now.year)
		searchURL = searchURL  + f'season=\'{season}\''
	else:
		searchURL = searchURL  + f'season=\'{season}\''

	resp = download(searchURL)

	#print(searchURL)
	resp_str = str(resp, 'UTF-8')
	#print(resp_str)

	resp_json = json.loads(resp_str)
	try:
		result_count = int(resp_json['org_game_type_date_info']['queryResults']['totalSize'])
	except:
		result_count = 0

	if result_count > 0:
		#print(resp_json['player_teams']['queryResults']['row'])
		#print(f'{result_count} statlines found,\nParsing results into a dataframe.')
		#players = resp_json['search_player_all']['queryResults']['row']
		main_df = json_normalize(resp_json['org_game_type_date_info']['queryResults']['row']) 
		#print('Done')
	else:
		print(f'No results found for the provided playerID. \nTry a diffrient search for better results.')
		
	return main_df
